@@ -8,7 +8,7 @@ def read(fname):
 
 setup(
     name = "solpy",
-    version = "0.2.1",
+    version = "0.2.4",
     author = "Nathan Charles",
     author_email = "ncharles@gmail.com",
     description = ("Solar Performance and Design library"),
@@ -17,8 +17,8 @@ setup(
     url = "https://github.com/nrcharles/solpy",
     packages=find_packages(),
     long_description=read('README'),
-    install_requires = ['geopy','numpy','matplotlib','scipy'],
-    package_data={'': ['*.json','*.csv','data.fdf']},
+    install_requires = ['geopy','numpy','matplotlib','scipy','pyephem'],
+    package_data={'': ['*.json','*.csv']},
     classifiers=[
         "Development Status :: 4 - Beta",
         "License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)",
